@@ -22,6 +22,7 @@ from pathlib import Path
 from typing import Any, Optional, Union
 
 from pydantic import Field
+from pydantic.types import StrBytes
 
 from .abstract_base import AbstractBase
 from .base_model import BaseModel
@@ -195,21 +196,62 @@ class Workspace(AbstractBase):
 
     @classmethod
     def load(cls, filename: Union[str, Path]) -> "Workspace":
-        """"""
+        """Load a workspace from a JSON file (which may optionally be gzipped)."""
         filename = Path(filename)
         try:
             with gzip.open(filename, "rt") as handle:
-                ws_io = WorkspaceIO.parse_raw(handle.read())
+                return cls.loads(handle.read())
         except FileNotFoundError as error:
             raise error
         except OSError:
             with filename.open() as handle:
-                ws_io = WorkspaceIO.parse_raw(handle.read())
+                return cls.loads(handle.read())
+
+    @classmethod
+    def loads(cls, json: StrBytes) -> "Workspace":
+        """Load a workspace from a JSON string or bytes."""
+        ws_io = WorkspaceIO.parse_raw(json)
         return cls.hydrate(ws_io)
 
+    def dump(
+        self,
+        filename: Union[str, Path],
+        *,
+        zip: Optional[bool] = None,
+        indent: Optional[int] = None,
+        **kwargs
+    ):
+        """
+        Save a workspace as JSON to a file, optionally gzipped.
+
+        By default, filenames ending with `.gz` will be zipped and anything else won't,
+        however this can be overridden by explicitly passing the `zip` argument.
+
+        Arguments:
+            filename: filename to write to.
+            zip: if specified then controls whether the contents are gzipped.
+            indent: if specified then pretty-print the JSON with given indent.
+            kwargs: other arguments to pass through to `json.dumps()`.
+        """
+        filename = Path(filename)
+        if zip is None:
+            zip = str(filename).endswith(".gz")
+        with gzip.open(filename, "wt") if zip else filename.open("wt") as handle:
+            handle.write(self.dumps(indent=indent, **kwargs))
+
+    def dumps(self, indent: Optional[int] = None, **kwargs):
+        """
+        Export a workspace as a JSON string.
+
+        Args:
+            indent (int): if specified then pretty-print the JSON with given indent.
+            kwargs: other arguments to pass through to `json.dumps()`.
+        """
+        return WorkspaceIO.from_orm(self).json(indent=indent, **kwargs)
+
     @classmethod
     def hydrate(cls, workspace_io: WorkspaceIO) -> "Workspace":
-        """"""
+        """Create a new instance of Workspace from its IO."""
         model = Model.hydrate(workspace_io.model)
         views = ViewSet.hydrate(views=workspace_io.views, model=model)
 
